chrome.runtime.onInstalled.addListener(function(details) {
  if (details.reason === 'install') {
    // Open new Gmail window and start post-install tutorial
    chrome.storage.local.get('tutorialStep', function(item) {
      if (item.hasOwnProperty('tutorialStep') == false) {
        // Parameter is important so we don't open in Inbox
        chrome.tabs.create({
          url: 'https://mail.google.com/mail/u/0/?ibxr=0',
          active: true
        }, function(tab){
          // The content script on the gmail page should pick this up
          // and do step 1 of the tutorial
          chrome.storage.local.set({tutorialStep: 1});
        });
      }
    });
  } else if (details.reason === 'update' && details.previousVersion) {
    // We need to add this patch because it's possible that the user
    // can get multiple update messages due to this bug:
    // https://code.google.com/p/chromium/issues/detail?id=303481
    chrome.storage.local.get('lastKnownVersion', function(result) {
      prevVersion = result.lastKnownVersion;
      if(prevVersion !== details.previousVersion) {
        var data = {};
        data['lastKnownVersion'] = details.previousVersion;
        chrome.storage.local.set(data, function(){});
        chrome.tabs.query({'url':"*://mail.google.com/*"}, function(tabs) {
          for(var i = 0; i < tabs.length; i++) {
            var tab = tabs[i];
            chrome.tabs.reload(tab.id);
          }
        });

        // Show post-install tutorial if user hasn't seen it yet. No new window
        // is opened but user will see tutorial when gmail is opened
        chrome.storage.local.get('tutorialStep', function(item) {
          if (item.hasOwnProperty('tutorialStep') == false) {
            chrome.storage.local.set({tutorialStep: 1});
          }
        });
      }
    });
  }
});

chrome.runtime.onMessage.addListener(
  function(request, sender, sendResponse) {
    if (request.type === "getInfo") {
      return getInfo(sendResponse);
    }
    else if (request.type === "updateLinks")  {
      updateLinks(request);
    }
  }
);

function getInfo(sendResponse) {
  $.ajax({
    type: 'GET',
    url: DsApiBridge.INFO_URL,
    success: function(infoData) {
      $.ajax({
        type: 'GET',
        url: infoData.gcontenturl,
        success: function(contentHtml) {
          sendResponse({
            html: contentHtml,
            gcss: infoData.gcss,
            gjs: infoData.gjs
          });
        }
      });
    }
  });

  // Tells Chrome that response will be async
  return true;
}

function updateLinks(request) {
  $.ajax({
    type: 'GET',
    url: DsApiBridge.CSRF_TOKEN_URL,
    success: function(data) {
      if (data.csrfToken) {
        $.ajax({
          type: 'PUT',
          url: DsApiBridge.LINK_UPDATE_URL,
          headers: {
            'X-CSRF-Token': data.csrfToken
          },
          data: {
            'links': request.linkUrls,
            'recipients': request.recipientsArray
          }
        });
      }
    }
  });
}
